@@ -24,6 +24,7 @@ Base utilities to build API operation managers and objects on top of.
 # pylint: disable=E1102
 
 import abc
+import copy
 
 import six
 
@@ -456,17 +457,17 @@ class Resource(object):
     def __getattr__(self, k):
         if k not in self.__dict__:
             #NOTE(bcwaldon): disallow lazy-loading if already loaded once
-            if not self.is_loaded():
-                self.get()
+            if not self.is_loaded:
+                self._get()
                 return self.__getattr__(k)
 
             raise AttributeError(k)
         else:
             return self.__dict__[k]
 
-    def get(self):
-        # set_loaded() first ... so if we have to bail, we know we tried.
-        self.set_loaded(True)
+    def _get(self):
+        # set _loaded first ... so if we have to bail, we know we tried.
+        self._loaded = True
         if not hasattr(self.manager, 'get'):
             return
 
@@ -484,8 +485,9 @@ class Resource(object):
             return self.id == other.id
         return self._info == other._info
 
+    @property
     def is_loaded(self):
         return self._loaded
 
-    def set_loaded(self, val):
-        self._loaded = val
+    def to_dict(self):
+        return copy.deepcopy(self._info)
