@@ -280,13 +280,15 @@ class TestGetTemplateContents(testtools.TestCase):
 
     def test_get_template_contents_file(self):
         with tempfile.NamedTemporaryFile() as tmpl_file:
-            tmpl = '{"foo": "bar"}'
+            tmpl = b'{"AWSTemplateFormatVersion" : "2010-09-09",' \
+                   b' "foo": "bar"}'
             tmpl_file.write(tmpl)
             tmpl_file.flush()
 
             files, tmpl_parsed = template_utils.get_template_contents(
                 tmpl_file.name)
-            self.assertEqual({"foo": "bar"}, tmpl_parsed)
+            self.assertEqual({"AWSTemplateFormatVersion": "2010-09-09",
+                              "foo": "bar"}, tmpl_parsed)
             self.assertEqual({}, files)
 
     def test_get_template_contents_file_empty(self):
@@ -301,18 +303,18 @@ class TestGetTemplateContents(testtools.TestCase):
                 'Could not fetch template from file://%s' % tmpl_file.name)
 
     def test_get_template_contents_file_none(self):
-            ex = self.assertRaises(
-                exc.CommandError,
-                template_utils.get_template_contents)
-            self.assertEqual(
-                str(ex),
-                ('Need to specify exactly one of --template-file, '
-                 '--template-url or --template-object'))
+        ex = self.assertRaises(
+            exc.CommandError,
+            template_utils.get_template_contents)
+        self.assertEqual(
+            str(ex),
+            ('Need to specify exactly one of --template-file, '
+             '--template-url or --template-object'))
 
     def test_get_template_contents_parse_error(self):
         with tempfile.NamedTemporaryFile() as tmpl_file:
 
-            tmpl = '{"foo": "bar"'
+            tmpl = b'{"foo": "bar"'
             tmpl_file.write(tmpl)
             tmpl_file.flush()
 
@@ -326,7 +328,7 @@ class TestGetTemplateContents(testtools.TestCase):
                     'Error parsing template file://%s ' % tmpl_file.name))
 
     def test_get_template_contents_url(self):
-        tmpl = '{"foo": "bar"}'
+        tmpl = '{"AWSTemplateFormatVersion" : "2010-09-09", "foo": "bar"}'
         url = 'http://no.where/path/to/a.yaml'
         self.m.StubOutWithMock(urlutils, 'urlopen')
         urlutils.urlopen(url).AndReturn(six.StringIO(tmpl))
@@ -334,11 +336,12 @@ class TestGetTemplateContents(testtools.TestCase):
 
         files, tmpl_parsed = template_utils.get_template_contents(
             template_url=url)
-        self.assertEqual({"foo": "bar"}, tmpl_parsed)
+        self.assertEqual({"AWSTemplateFormatVersion": "2010-09-09",
+                          "foo": "bar"}, tmpl_parsed)
         self.assertEqual({}, files)
 
     def test_get_template_contents_object(self):
-        tmpl = '{"foo": "bar"}'
+        tmpl = '{"AWSTemplateFormatVersion" : "2010-09-09", "foo": "bar"}'
         url = 'http://no.where/path/to/a.yaml'
         self.m.ReplayAll()
 
@@ -354,7 +357,8 @@ class TestGetTemplateContents(testtools.TestCase):
             template_object=url,
             object_request=object_request)
 
-        self.assertEqual({"foo": "bar"}, tmpl_parsed)
+        self.assertEqual({"AWSTemplateFormatVersion": "2010-09-09",
+                          "foo": "bar"}, tmpl_parsed)
         self.assertEqual({}, files)
         self.assertTrue(self.object_requested)
 
@@ -452,6 +456,23 @@ resources:
 
         self.m.VerifyAll()
 
+    def test_hot_template_outputs(self):
+        self.m.StubOutWithMock(urlutils, 'urlopen')
+        tmpl_file = '/home/my/dir/template.yaml'
+        url = 'file://%s' % tmpl_file
+        contents = str('heat_template_version: 2013-05-23\n'
+                       'outputs:\n'
+                       '  contents:\n'
+                       '    value:\n'
+                       '      get_file: template.yaml\n')
+        urlutils.urlopen(url).AndReturn(six.StringIO(contents))
+        urlutils.urlopen(url).AndReturn(six.StringIO(contents))
+        self.m.ReplayAll()
+        files, tmpl_parsed = template_utils.get_template_contents(
+            template_file=tmpl_file)
+        self.assertEqual({url: contents}, files)
+        self.m.VerifyAll()
+
 
 class TestURLFunctions(testtools.TestCase):
 
