@@ -18,6 +18,7 @@ import yaml
 from heatclient.common import template_utils
 from heatclient.common import utils
 from heatclient.openstack.common import jsonutils
+from heatclient.openstack.common.py3kcompat import urlutils
 
 import heatclient.exc as exc
 
@@ -29,16 +30,16 @@ import heatclient.exc as exc
 @utils.arg('-u', '--template-url', metavar='<URL>',
            help='URL of template.')
 @utils.arg('-o', '--template-object', metavar='<URL>',
-           help='URL to retrieve template object (e.g from swift)')
+           help='URL to retrieve template object (e.g. from swift).')
 @utils.arg('-c', '--create-timeout', metavar='<TIMEOUT>',
            default=60, type=int,
-           help='Stack creation timeout in minutes. Default: 60')
+           help='Stack creation timeout in minutes. Default: 60.')
 @utils.arg('-r', '--enable-rollback', default=False, action="store_true",
-           help='Enable rollback on create/update failure')
+           help='Enable rollback on create/update failure.')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values used to create the stack. '
            'This can be specified multiple times, or once with parameters '
-           'separated by semicolon.',
+           'separated by a semicolon.',
            action='append')
 @utils.arg('name', metavar='<STACK_NAME>',
            help='Name of the stack to create.')
@@ -54,16 +55,16 @@ def do_create(hc, args):
 @utils.arg('-u', '--template-url', metavar='<URL>',
            help='URL of template.')
 @utils.arg('-o', '--template-object', metavar='<URL>',
-           help='URL to retrieve template object (e.g from swift)')
+           help='URL to retrieve template object (e.g. from swift).')
 @utils.arg('-c', '--create-timeout', metavar='<TIMEOUT>',
            default=60, type=int,
-           help='Stack creation timeout in minutes. Default: 60')
+           help='Stack creation timeout in minutes. Default: 60.')
 @utils.arg('-r', '--enable-rollback', default=False, action="store_true",
-           help='Enable rollback on create/update failure')
+           help='Enable rollback on create/update failure.')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values used to create the stack. '
            'This can be specified multiple times, or once with parameters '
-           'separated by semicolon.',
+           'separated by a semicolon.',
            action='append')
 @utils.arg('name', metavar='<STACK_NAME>',
            help='Name of the stack to create.')
@@ -83,7 +84,60 @@ def do_stack_create(hc, args):
         'disable_rollback': not(args.enable_rollback),
         'parameters': utils.format_parameters(args.parameters),
         'template': template,
-        'files': dict(tpl_files.items() + env_files.items()),
+        'files': dict(list(tpl_files.items()) + list(env_files.items())),
+        'environment': env
+    }
+
+    hc.stacks.create(**fields)
+    do_stack_list(hc)
+
+
+@utils.arg('-f', '--template-file', metavar='<FILE>',
+           help='Path to the template.')
+@utils.arg('-e', '--environment-file', metavar='<FILE or URL>',
+           help='Path to the environment.')
+@utils.arg('-u', '--template-url', metavar='<URL>',
+           help='URL of template.')
+@utils.arg('-o', '--template-object', metavar='<URL>',
+           help='URL to retrieve template object (e.g from swift).')
+@utils.arg('-c', '--create-timeout', metavar='<TIMEOUT>',
+           default=60, type=int,
+           help='Stack creation timeout in minutes. Default: 60.')
+@utils.arg('-a', '--adopt-file', metavar='<FILE or URL>',
+           help='Path to adopt stack data file.')
+@utils.arg('-r', '--enable-rollback', default=False, action="store_true",
+           help='Enable rollback on create/update failure.')
+@utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
+           help='Parameter values used to create the stack. '
+           'This can be specified multiple times, or once with parameters '
+           'separated by a semicolon.',
+           action='append')
+@utils.arg('name', metavar='<STACK_NAME>',
+           help='Name of the stack to adopt.')
+def do_stack_adopt(hc, args):
+    '''Adopt a stack.'''
+    tpl_files, template = template_utils.get_template_contents(
+        args.template_file,
+        args.template_url,
+        args.template_object,
+        hc.http_client.raw_request)
+    env_files, env = template_utils.process_environment_and_files(
+        env_path=args.environment_file)
+
+    if not args.adopt_file:
+        raise exc.CommandError('Need to specify --adopt-file')
+
+    adopt_url = template_utils.normalise_file_path_to_url(args.adopt_file)
+    adopt_data = urlutils.urlopen(adopt_url).read()
+
+    fields = {
+        'stack_name': args.name,
+        'timeout_mins': args.create_timeout,
+        'disable_rollback': not(args.enable_rollback),
+        'adopt_stack_data': adopt_data,
+        'parameters': utils.format_parameters(args.parameters),
+        'template': template,
+        'files': dict(list(tpl_files.items()) + list(env_files.items())),
         'environment': env
     }
 
@@ -190,11 +244,11 @@ def do_stack_show(hc, args):
 @utils.arg('-u', '--template-url', metavar='<URL>',
            help='URL of template.')
 @utils.arg('-o', '--template-object', metavar='<URL>',
-           help='URL to retrieve template object (e.g from swift)')
+           help='URL to retrieve template object (e.g. from swift).')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values used to create the stack. '
            'This can be specified multiple times, or once with parameters '
-           'separated by semicolon.',
+           'separated by a semicolon.',
            action='append')
 @utils.arg('id', metavar='<NAME or ID>',
            help='Name or ID of stack to update.')
@@ -210,11 +264,11 @@ def do_update(hc, args):
 @utils.arg('-u', '--template-url', metavar='<URL>',
            help='URL of template.')
 @utils.arg('-o', '--template-object', metavar='<URL>',
-           help='URL to retrieve template object (e.g from swift)')
+           help='URL to retrieve template object (e.g. from swift).')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values used to create the stack. '
            'This can be specified multiple times, or once with parameters '
-           'separated by semicolon.',
+           'separated by a semicolon.',
            action='append')
 @utils.arg('id', metavar='<NAME or ID>',
            help='Name or ID of stack to update.')
@@ -234,7 +288,7 @@ def do_stack_update(hc, args):
         'stack_id': args.id,
         'parameters': utils.format_parameters(args.parameters),
         'template': template,
-        'files': dict(tpl_files.items() + env_files.items()),
+        'files': dict(list(tpl_files.items()) + list(env_files.items())),
         'environment': env
     }
 
@@ -250,12 +304,12 @@ def do_list(hc, args=None):
 @utils.arg('-f', '--filters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Filter parameters to apply on returned stacks. '
            'This can be specified multiple times, or once with parameters '
-           'separated by semicolon.',
+           'separated by a semicolon.',
            action='append')
 @utils.arg('-l', '--limit', metavar='<LIMIT>',
-           help='Limit the number of stacks returned')
+           help='Limit the number of stacks returned.')
 @utils.arg('-m', '--marker', metavar='<ID>',
-           help='Only return stacks that appear after the given stack ID')
+           help='Only return stacks that appear after the given stack ID.')
 def do_stack_list(hc, args=None):
     '''List the user's stacks.'''
     kwargs = {}
@@ -269,6 +323,46 @@ def do_stack_list(hc, args=None):
     utils.print_list(stacks, fields, sortby=3)
 
 
+@utils.arg('id', metavar='<NAME or ID>',
+           help='Name or ID of stack to query.')
+def do_output_list(hc, args):
+    '''Show available outputs.'''
+    try:
+        stack = hc.stacks.get(stack_id=args.id)
+    except exc.HTTPNotFound:
+        raise exc.CommandError('Stack not found: %s' % args.id)
+    else:
+        outputs = stack.to_dict()['outputs']
+        fields = ['output_key', 'description']
+        formatters = {
+            'output_key': lambda x: x['output_key'],
+            'description': lambda x: x['description'],
+        }
+
+        utils.print_list(outputs, fields, formatters=formatters)
+
+
+@utils.arg('id', metavar='<NAME or ID>',
+           help='Name or ID of stack to query.')
+@utils.arg('output', metavar='<OUTPUT NAME>',
+           help='Name of an output to display.')
+def do_output_show(hc, args):
+    '''Show a specific stack output.'''
+    try:
+        stack = hc.stacks.get(stack_id=args.id)
+    except exc.HTTPNotFound:
+        raise exc.CommandError('Stack not found: %s' % args.id)
+    else:
+        for output in stack.to_dict().get('outputs', []):
+            if output['output_key'] == args.output:
+                value = output['output_value']
+                break
+        else:
+            return
+
+        print (jsonutils.dumps(value, indent=2))
+
+
 def do_resource_type_list(hc, args={}):
     '''List the available resource types.'''
     kwargs = {}
@@ -277,7 +371,7 @@ def do_resource_type_list(hc, args={}):
 
 
 @utils.arg('resource_type', metavar='<RESOURCE_TYPE>',
-           help='Resource Type to get the details for.')
+           help='Resource type to get the details for.')
 def do_resource_type_show(hc, args={}):
     '''Show the resource type.'''
     try:
@@ -319,11 +413,11 @@ def do_template_show(hc, args):
 @utils.arg('-e', '--environment-file', metavar='<FILE or URL>',
            help='Path to the environment.')
 @utils.arg('-o', '--template-object', metavar='<URL>',
-           help='URL to retrieve template object (e.g from swift)')
+           help='URL to retrieve template object (e.g. from swift).')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values to validate. '
            'This can be specified multiple times, or once with parameters '
-           'separated by semicolon.',
+           'separated by a semicolon.',
            action='append')
 def do_validate(hc, args):
     '''DEPRECATED! Use template-validate instead.'''
@@ -337,11 +431,11 @@ def do_validate(hc, args):
 @utils.arg('-e', '--environment-file', metavar='<FILE or URL>',
            help='Path to the environment.')
 @utils.arg('-o', '--template-object', metavar='<URL>',
-           help='URL to retrieve template object (e.g from swift)')
+           help='URL to retrieve template object (e.g. from swift).')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values to validate. '
            'This can be specified multiple times, or once with parameters '
-           'separated by semicolon.',
+           'separated by a semicolon.',
            action='append')
 def do_template_validate(hc, args):
     '''Validate a template with parameters.'''
@@ -357,7 +451,7 @@ def do_template_validate(hc, args):
     fields = {
         'parameters': utils.format_parameters(args.parameters),
         'template': template,
-        'files': dict(tpl_files.items() + env_files.items()),
+        'files': dict(list(tpl_files.items()) + list(env_files.items())),
         'environment': env
     }
 
@@ -418,7 +512,7 @@ def do_resource_show(hc, args):
 @utils.arg('resource', metavar='<RESOURCE>',
            help='Name of the resource to generate a template for.')
 @utils.arg('-F', '--format', metavar='<FORMAT>',
-           help="The template output format, one of: %s"
+           help="The template output format, one of: %s."
                 % ', '.join(utils.supported_formats.keys()))
 def do_resource_template(hc, args):
     '''Generate a template based on a resource.'''
@@ -451,10 +545,44 @@ def do_resource_metadata(hc, args):
         print(jsonutils.dumps(metadata, indent=2))
 
 
+@utils.arg('id', metavar='<NAME or ID>',
+           help='Name or ID of stack the resource belongs to.')
+@utils.arg('resource', metavar='<RESOURCE>',
+           help='Name of the resource to signal.')
+@utils.arg('-D', '--data', metavar='<DATA>',
+           help='JSON Data to send to the signal handler.')
+@utils.arg('-f', '--data-file', metavar='<FILE>',
+           help='File containing JSON data to send to the signal handler.')
+def do_resource_signal(hc, args):
+    '''Send a signal to a resource.'''
+    fields = {'stack_id': args.id,
+              'resource_name': args.resource}
+    data = args.data
+    data_file = args.data_file
+    if data and data_file:
+        raise exc.CommandError('Can only specify one of data and data-file')
+    if data_file:
+        data_url = template_utils.normalise_file_path_to_url(data_file)
+        data = urlutils.urlopen(data_url).read()
+    if data:
+        try:
+            data = jsonutils.loads(data)
+        except ValueError as ex:
+            raise exc.CommandError('Data should be in JSON format: %s' % ex)
+        if not isinstance(data, dict):
+            raise exc.CommandError('Data should be a JSON dict')
+        fields['data'] = data
+    try:
+        hc.resources.signal(**fields)
+    except exc.HTTPNotFound:
+        raise exc.CommandError('Stack or resource not found: %s %s' %
+                               (args.id, args.resource))
+
+
 @utils.arg('id', metavar='<NAME or ID>',
            help='Name or ID of stack to show the events for.')
 @utils.arg('-r', '--resource', metavar='<RESOURCE>',
-           help='Name of the resource to filter events by')
+           help='Name of the resource to filter events by.')
 def do_event_list(hc, args):
     '''List events for a stack.'''
     fields = {'stack_id': args.id,
@@ -481,7 +609,7 @@ def do_event_list(hc, args):
 @utils.arg('resource', metavar='<RESOURCE>',
            help='Name of the resource the event belongs to.')
 @utils.arg('event', metavar='<EVENT>',
-           help='ID of event to display details for')
+           help='ID of event to display details for.')
 def do_event(hc, args):
     '''DEPRECATED! Use event-show instead.'''
     do_event_show(hc, args)
@@ -492,7 +620,7 @@ def do_event(hc, args):
 @utils.arg('resource', metavar='<RESOURCE>',
            help='Name of the resource the event belongs to.')
 @utils.arg('event', metavar='<EVENT>',
-           help='ID of event to display details for')
+           help='ID of event to display details for.')
 def do_event_show(hc, args):
     '''Describe the event.'''
     fields = {'stack_id': args.id,
